import 'package:easy_localization/src/public_ext.dart';
import 'package:flutter/material.dart';
import 'package:flutter_staggered_animations/flutter_staggered_animations.dart';
import 'package:infinite_scroll_pagination/infinite_scroll_pagination.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';
import 'package:scroll_to_index/scroll_to_index.dart';
import '../../../widget/custom/custom_icon.dart';
import '../../../widget/custom/spaces.dart';
import '../../../widget/pages/page_empty_data_widget.dart';
import '../../../widget/pages/page_loading_ui_widget.dart';
import '../../../widget/pages/page_loading_widget.dart';
import '../../../widget/text/custom_text_default_italic_field.dart';

class BaseCustomListScrollView<T> extends StatelessWidget {
  final PagingController<int, T> pagingController;
  final Function(T, int) itemBuilder;
  final AutoScrollController? controller;
  final bool? isLastPage;
  final String? message;
  final bool? isController;
  final VoidCallback onRefresh;
  final bool? isPrimary;
  final RefreshController refreshController;

  const BaseCustomListScrollView({
    required this.pagingController,
    required this.itemBuilder,
    required this.controller,
    required this.onRefresh,
    required this.refreshController,
    this.isPrimary = true,
    this.isController = true,
    this.isLastPage = false,
    this.message,
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SmartRefresher(
      physics: BouncingScrollPhysics(),
      header: WaterDropMaterialHeader(
        color: isPrimary == true
            ? Colors.white
            : Theme.of(context).primaryColorLight,
        backgroundColor: isPrimary == true
            ? Theme.of(context).primaryColorDark
            : Colors.white,
      ),
      enablePullDown: true,
      onRefresh: onRefresh,
      controller: refreshController,
      child: CustomScrollView(
        controller: controller,
        scrollDirection: Axis.vertical,
        physics: BouncingScrollPhysics(),
        slivers: [
          SliverPadding(
            padding: EdgeInsets.only(top: 4),
            sliver: PagedSliverList.separated(
              addAutomaticKeepAlives: true,
              pagingController: pagingController,
              separatorBuilder: (BuildContext context, int index) => SpaceH6(),
              builderDelegate: PagedChildBuilderDelegate<T>(
                itemBuilder: (context, item, index) {
                  return AnimationConfiguration.staggeredList(
                    position: index,
                    child: FadeInAnimation(
                        duration: Duration(milliseconds: 150),
                        child: SlideAnimation(
                            duration: Duration(milliseconds: 100),
                            verticalOffset: 10,
                            child: itemBuilder(item, index))),
                  );
                },
                newPageProgressIndicatorBuilder: (context) {
                  if (isLastPage == false) {
                    return LoadingPageWidget();
                  } else {
                    return Container();
                  }
                },
                noMoreItemsIndicatorBuilder: (context) {
                  var dataSize = pagingController.itemList?.length ?? 0;
                  if (dataSize > 10) {
                    return Container(
                      child: Column(
                        children: [
                          CustomIcon(icon: Icons.search_rounded),
                          CustomTextDefaultItalicField(
                              label: "text_no_more".tr())
                        ],
                      ),
                    );
                  } else {
                    return Container();
                  }
                },
                firstPageProgressIndicatorBuilder: (context) => Padding(
                  padding: const EdgeInsets.only(top: 60),
                  child: LoadingUIPageWidget(isCart: false, msg: message),
                ),
                noItemsFoundIndicatorBuilder: (context) {
                  return Padding(
                      padding: EdgeInsets.only(top: 60),
                      child: EmptyUIPageWidget(
                          isBackgroundWhite: false, msg: message));
                },
              ),
              shrinkWrapFirstPageIndicators: true,
            ),
          ),
        ],
      ),
    );
  }
}
